agentle.agents.agent\_protocol
==============================

.. automodule:: agentle.agents.agent_protocol

   
   .. rubric:: Functions

   .. autosummary::
   
      asynccontextmanager
      contextmanager
      runtime_checkable
   
   .. rubric:: Classes

   .. autosummary::
   
      AgentProtocol
      Any
      AsyncGenerator
      Generator
      Protocol
   